@@ -33,7 +33,6 @@ import six
 
 from rattail.db import api, model
 from rattail.batch import BatchHandler
-from rattail.gpc import GPC
 from rattail.time import make_utc
 from rattail.wince import parse_batch_file as parse_wince_file
 
@@ -90,7 +89,7 @@ class HandheldBatchHandler(BatchHandler):
 
             def convert(entry, i):
                 scancode, cases, units = entry
-                upc = GPC(int(scancode), calc_check_digit='upc')
+                upc = self.app.make_gpc(int(scancode), calc_check_digit='upc')
                 data.append((
                     upc,
                     cases or None,
@@ -102,15 +101,20 @@ class HandheldBatchHandler(BatchHandler):
         else:                   # presumably csv, converted from raw file
 
             def convert(entry, i):
-                upc = GPC(entry['upc'], calc_check_digit='upc')
+                upc = self.app.make_gpc(entry['upc'], calc_check_digit='upc')
                 data.append((
                     upc,
                     decimal.Decimal(entry['cases']) if entry['cases'] else None,
                     decimal.Decimal(entry['units']) if entry['units'] else None,
                 ))
 
+            # try to detect tab- vs. comma-delimited CSV
+            delimiter = ','
+            if '\t' in line:
+                delimiter = '\t'
+
             with open(path, filemode) as f:
-                reader = csv.DictReader(f)
+                reader = csv.DictReader(f, delimiter=delimiter)
                 entries = list(reader)
 
         self.progress_loop(convert, entries, progress,
@@ -125,7 +129,7 @@ class HandheldBatchHandler(BatchHandler):
 
         def convert(entry, i):
             data.append((
-                GPC(entry['upc'], calc_check_digit='upc'),
+                self.app.make_gpc(entry['upc'], calc_check_digit='upc'),
                 int(entry['cases']),
                 int(entry['units']),
             ))
