@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Backup commands
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import re
 import shutil
@@ -34,8 +32,6 @@ import subprocess
 import sys
 import logging
 
-import six
-
 from rattail.commands.core import Subcommand
 from rattail.config import parse_bool, parse_list
 
@@ -396,9 +392,18 @@ class Backup(Subcommand):
             for prefix in prefixes:
                 cmd.append(prefix)
 
+            # run `borg create`
             log.debug("borg create command is: %s", cmd)
             if not dry_run:
-                subprocess.check_call(cmd, env=borg_env)
+                try:
+                    subprocess.check_call(cmd, env=borg_env)
+                except subprocess.CalledProcessError as error:
+                    # nb. borg exits with code 1 for "warning" but
+                    # this is different than "error" - cf. also
+                    # https://borgbackup.readthedocs.io/en/latest/man_intro.html#return-codes
+                    if error.returncode != 1:
+                        raise
+                    log.warning("borg create command exited with code 1")
 
             # the only thing left is to prune, which if we're tagging, we
             # probably should just skip.  maybe let command line override?
@@ -441,7 +446,7 @@ class Backup(Subcommand):
                 '--batch', '--skip-column-names',
             ])
         except Exception as error:
-            if six.PY3 and isinstance(error, FileNotFoundError):
+            if isinstance(error, FileNotFoundError):
                 # assuming there is no mysql binary
                 return []
             raise
@@ -471,7 +476,7 @@ class Backup(Subcommand):
                 database,
             ])
         except Exception as error:
-            if six.PY3 and isinstance(error, FileNotFoundError):
+            if isinstance(error, FileNotFoundError):
                 # assuming there is no mysql binary
                 return []
             raise
