@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Database Stuff
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import sys
 import logging
@@ -93,7 +91,7 @@ if sqlalchemy:
             if isinstance(user_info, model.User):
                 user = self.merge(user_info)
             else:
-                user = self.query(model.User).get(user_info)
+                user = self.get(model.User, user_info)
                 if not user:
                     try:
                         user = self.query(model.User).filter_by(username=user_info).one()
