@@ -35,7 +35,8 @@ def upgrade():
     op.add_column('purchase_batch', sa.Column('mode', sa.Integer(), nullable=True))
     batch = sa.sql.table('purchase_batch', sa.sql.column('mode'))
     op.execute(batch.update().values({'mode': enum.PURCHASE_BATCH_MODE_ORDERING}))
-    op.alter_column('purchase_batch', 'mode', nullable=False)
+    op.alter_column('purchase_batch', 'mode', nullable=False,
+                    existing_type=sa.Integer())
 
 
 def downgrade():
