@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Rattail -> Rattail data import
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
 
 import sqlalchemy as sa
@@ -78,8 +76,7 @@ class ToRattailHandler(ToSQLAlchemyHandler):
         # load "runas user" into current session
         if hasattr(self, 'runas_user') and self.runas_user:
             dbmodel = self.config.get_model()
-            runas_user = self.session.query(dbmodel.User)\
-                                     .get(self.runas_user.uuid)
+            runas_user = self.session.get(dbmodel.User, self.runas_user.uuid)
             if not runas_user:
                 log.info("runas_user does not exist in target session: %s",
                          self.runas_user.username)
@@ -132,6 +129,7 @@ class FromRattailToRattailBase(object):
         importers['VendorEmailAddress'] = VendorEmailAddressImporter
         importers['VendorPhoneNumber'] = VendorPhoneNumberImporter
         importers['VendorContact'] = VendorContactImporter
+        importers['VendorSampleFile'] = VendorSampleFileImporter
         importers['Department'] = DepartmentImporter
         importers['EmployeeDepartment'] = EmployeeDepartmentImporter
         importers['Subdepartment'] = SubdepartmentImporter
@@ -354,7 +352,7 @@ class GlobalRoleImporter(RoleImporter):
             # add some users
             for new_user in new_users:
                 if new_user not in old_users:
-                    user = self.session.query(model.User).get(new_user)
+                    user = self.session.get(model.User, new_user)
                     if user:
                         user.roles.append(role)
                         changed = True
@@ -362,7 +360,7 @@ class GlobalRoleImporter(RoleImporter):
             # remove some users
             for old_user in old_users:
                 if old_user not in new_users:
-                    user = self.session.query(model.User).get(old_user)
+                    user = self.session.get(model.User, old_user)
                     if user:
                         user.roles.remove(role)
                         changed = True
@@ -514,6 +512,9 @@ class VendorPhoneNumberImporter(FromRattail, model.VendorPhoneNumberImporter):
 class VendorContactImporter(FromRattail, model.VendorContactImporter):
     pass
 
+class VendorSampleFileImporter(FromRattail, model.VendorSampleFileImporter):
+    pass
+
 class DepartmentImporter(FromRattail, model.DepartmentImporter):
     pass
 
