@@ -26,11 +26,8 @@ People Handler
 See also :doc:`rattail-manual:base/handlers/other/people`.
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import warnings
 
-import six
 import sqlalchemy as sa
 
 from rattail.app import GenericHandler, MergeMixin
@@ -74,7 +71,7 @@ class PeopleHandler(GenericHandler, MergeMixin):
             person.display_name = self.normalize_full_name(
                 person.first_name, person.last_name)
 
-        for key, value in six.iteritems(kwargs):
+        for key, value in kwargs.items():
             if hasattr(person, key):
                 setattr(person, key, value)
 
@@ -363,13 +360,13 @@ class PeopleHandler(GenericHandler, MergeMixin):
         session = self.get_session(merge)
         model = self.model
 
-        removing = session.query(model.Person).get(merge.removing_uuid)
-        keeping = session.query(model.Person).get(merge.keeping_uuid)
+        removing = session.get(model.Person, merge.removing_uuid)
+        keeping = session.get(model.Person, merge.keeping_uuid)
 
         context = {
             'user_display': merge.requested_by.display_name,
-            'removing_display': six.text_type(removing) if removing else "(not found)",
-            'keeping_display': six.text_type(keeping) if keeping else "(not found)",
+            'removing_display': str(removing) if removing else "(not found)",
+            'keeping_display': str(keeping) if keeping else "(not found)",
         }
 
         url = self.config.base_url()
