@@ -24,13 +24,10 @@
 Products Handler
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import decimal
 import warnings
 import logging
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -70,8 +67,8 @@ class ProductsHandler(GenericHandler, MergeMixin):
            then returns ``None``.
         """
         # normalize to string; remove unwanted chars
-        if not isinstance(value, six.string_types):
-            value = six.text_type(value)
+        if not isinstance(value, str):
+            value = str(value)
         value = value.replace(' ', '')
         value = value.replace('-', '')
 
@@ -162,140 +159,6 @@ class ProductsHandler(GenericHandler, MergeMixin):
         return self.config.getbool('rattail', 'products.units_only',
                                    default=False)
 
-    # TODO: deprecate / remove (afaik it is not being used?)
-    def find_products_by_key(self, session, value, **kwargs):
-        """
-        Locate any products where the "key" matches the given value.
-
-        By default this search is as "thorough" as possible and may
-        return multiple results in some cases where you might not
-        expect them.  Please pass the ``only`` param if you need a
-        more focused search etc.
-
-        :param session: Session for the Rattail database.
-
-        :param value: Value to search for.  Can be a GPC object or
-           string.
-
-        :param only: You can optionally direct the logic to search
-           only for certain types of keys, by passing a list here,
-           e.g.  ``['upc', 'sku']``, or can just pass a single string
-           (e.g. ``'upc'``) if only one key is needed.  Otherwise by
-           default the logic will search for "all" possible keys.
-
-        :param vendor: You can optionally specify a Vendor, if your
-           search needs to include a SKU lookup.  Only matches for
-           that vendor will be returned.  Note that by default there
-           is no vendor which means "any" SKU might match.
-
-        :param include_keys: You can optionally request that the
-           return value include indications of which key was matched,
-           for each product result.
-
-        :returns: If ``include_keys`` is true, then will return a list
-           of 2-tuples representing each match.  The first element of
-           the tuple will be the "key" field pseudonym which was
-           matched on; the second element will be the product.
-
-           But if ``include_keys`` is false, then will return just a
-           simple list of the products, i.e. won't include the keys.
-
-           Either way of course the list might be empty.
-        """
-        from rattail.db.api.products import (get_product_by_upc,
-                                             get_product_by_item_id,
-                                             get_product_by_scancode,
-                                             get_product_by_code,
-                                             get_product_by_vendor_code)
-
-        model = self.model
-        only = kwargs.get('only')
-        if isinstance(only, six.string_types):
-            only = [only]
-        vendor = kwargs.get('vendor')
-        include_keys = kwargs.get('include_keys', False)
-        products = []
-
-        # don't bother if we're given empty value
-        if not value:
-            return products
-
-        # TODO: most of the function calls below are only good for "at
-        # most one" result.  in some cases there may be more than one
-        # match in fact, which will raise an error.  need to refactor
-        # somehow to account for that..for now just pass `only` param
-        # to avoid the problematic keys for your situation.
-
-        # maybe look for 'uuid' match
-        if not only or 'uuid' in only:
-            product = session.query(model.Product).get(value)
-            if product:
-                products.append(('uuid', product))
-
-        # maybe look for 'upc' match
-        if not only or 'upc' in only:
-
-            # if value is a GPC we kind of only have one thing to try
-            if isinstance(value, GPC):
-                product = get_product_by_upc(session, value)
-                if product:
-                    products.append(('upc', product))
-
-            else: # not GPC, so must convert
-
-                if value.isdigit():
-
-                    # we first assume the value *does* include check digit
-                    provided = GPC(value, calc_check_digit=False)
-                    product = get_product_by_upc(session, provided)
-                    if product:
-                        products.append(('upc', product))
-
-                    # but we can also calculate a check digit and try that
-                    checked = GPC(value, calc_check_digit='upc')
-                    product = get_product_by_upc(session, checked)
-                    if product:
-                        products.append(('upc', product))
-
-                    # one last trick is to expand UPC-E to UPC-A and then reattempt
-                    # the lookup, *with* check digit (since it would be known)
-                    if len(value) in (6, 8):
-                        checked = GPC(upce_to_upca(value), calc_check_digit='upc')
-                        product = get_product_by_upc(session, checked)
-                        if product:
-                            products.append(('upc', product))
-
-        # maybe look for 'item_id' match
-        if not only or 'item_id' in only:
-            product = get_product_by_item_id(session, value)
-            if product:
-                products.append(('item_id', product))
-
-        # maybe look for 'scancode' match
-        if not only or 'scancode' in only:
-            product = get_product_by_scancode(session, value)
-            if product:
-                products.append(('scancode', product))
-
-        # maybe look for 'altcode' match
-        if not only or 'altcode' in only:
-            product = get_product_by_code(session, value)
-            if product:
-                products.append(('altcode', product))
-
-        # maybe look for 'sku' match
-        if not only or 'sku' in only:
-            product = get_product_by_vendor_code(session, value,
-                                                 vendor=vendor)
-            if product:
-                products.append(('sku', product))
-
-        # maybe strip keys out of the result
-        if not include_keys:
-            products = [tup[1] for tup in products]
-
-        return products
-
     def locate_product_for_entry(self, session, entry, **kwargs):
         """
         This method aims to provide sane default logic for locating a
@@ -362,8 +225,8 @@ class ProductsHandler(GenericHandler, MergeMixin):
         # try to locate product by uuid before other, more specific key
         # if kwargs.get('try_uuid', True):
         if 'uuid' in lookup_fields:
-            if isinstance(entry, six.string_types):
-                product = session.query(model.Product).get(entry)
+            if isinstance(entry, str):
+                product = session.get(model.Product, entry)
                 if product:
                     return product
 
@@ -414,7 +277,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
             return
 
         # assume entry is string; valid only if all digits
-        entry = six.text_type(entry)
+        entry = str(entry)
         if not entry.isdigit():
             return
 
@@ -461,7 +324,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
             return
 
         # assume entry is string
-        entry = six.text_type(entry)
+        entry = str(entry)
 
         # do basic lookup
         return get_product_by_item_id(session, entry)
@@ -489,7 +352,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
             return
 
         # assume entry is string
-        entry = six.text_type(entry)
+        entry = str(entry)
 
         # do basic lookup
         return get_product_by_scancode(session, entry)
@@ -550,13 +413,27 @@ class ProductsHandler(GenericHandler, MergeMixin):
         :returns: First :class:`~rattail.db.model.products.Product`
            instance found if there was a match; otherwise ``None``.
         """
-        from rattail.db.api.products import get_product_by_upc
-
         if not gpc:
             return
 
+        model = self.model
+
+        def lookup(gpc_):
+            products = session.query(model.Product)\
+                              .filter(model.Product.upc == gpc_)
+
+            # TODO: do we need to support this kwarg?
+            #if not kwargs.get('include_deleted'):
+            products = products.filter(model.Product.deleted == False)
+
+            # TODO: maybe should just use first() instead?
+            try:
+                return products.one()
+            except orm.exc.NoResultFound:
+                pass
+
         # first we try the normal search
-        product = get_product_by_upc(session, gpc)
+        product = lookup(gpc)
         if product:
             return product
 
@@ -564,7 +441,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
         if gpc.type2_upc and self.convert_type2_for_gpc_lookup():
             cleaned = self.make_gpc('002{}00000'.format(gpc.data_str[1:6]),
                                     calc_check_digit='upc')
-            return get_product_by_upc(session, cleaned)
+            return lookup(cleaned)
 
     def convert_type2_for_gpc_lookup(self):
         return self.config.getbool(
@@ -652,7 +529,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
             'product_key': self.render_product_key(product),
             'description': product.description,
             'size': product.size,
-            '_str': six.text_type(product),
+            '_str': str(product),
         }
 
         if not fields:
@@ -699,6 +576,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
                 })
             data['costs'] = costs
 
+        current_price = None
         if not product.not_for_sale:
 
             margin_fields = [
@@ -726,7 +604,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
                     current_ends = current_price.ends
                     if current_ends:
                         current_ends = self.app.localtime(current_ends, from_utc=True).date()
-                        data['current_ends'] = six.text_type(current_ends)
+                        data['current_ends'] = str(current_ends)
                         data['current_ends_display'] = self.app.render_date(current_ends)
 
             sale_fields = [
@@ -744,7 +622,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
                     sale_ends = sale_price.ends
                     if sale_ends:
                         sale_ends = self.app.localtime(sale_ends, from_utc=True).date()
-                        data['sale_ends'] = six.text_type(sale_ends)
+                        data['sale_ends'] = str(sale_ends)
                         data['sale_ends_display'] = self.app.render_date(sale_ends)
 
             tpr_fields = [
@@ -762,7 +640,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
                     tpr_ends = tpr_price.ends
                     if tpr_ends:
                         tpr_ends = self.app.localtime(tpr_ends, from_utc=True).date()
-                        data['tpr_ends'] = six.text_type(tpr_ends)
+                        data['tpr_ends'] = str(tpr_ends)
                         data['tpr_ends_display'] = self.app.render_date(tpr_ends)
 
         if 'case_quantity' in fields:
@@ -773,13 +651,13 @@ class ProductsHandler(GenericHandler, MergeMixin):
             case_price = None
             if product.regular_price and product.regular_price is not None:
                 case_size = self.get_case_size(product)
-                # use sale price if there is one, else normal unit price
+                # use "current" price if there is one, else normal unit price
                 unit_price = product.regular_price.price
-                if sale_price:
-                    unit_price = sale_price.price
+                if current_price:
+                    unit_price = current_price.price
                 case_price = (case_size or 1) * unit_price
                 case_price = case_price.quantize(decimal.Decimal('0.01'))
-            data['case_price'] = six.text_type(case_price) if case_price is not None else None
+            data['case_price'] = str(case_price) if case_price is not None else None
             data['case_price_display'] = self.app.render_currency(case_price)
 
         if 'uom_choices' in fields:
@@ -896,7 +774,7 @@ class ProductsHandler(GenericHandler, MergeMixin):
         product_key = self.config.product_key()
         if product_key == 'upc':
             return self.app.render_gpc(product.upc)
-        return six.text_type(getattr(product, product_key))
+        return str(getattr(product, product_key))
 
     def render_price(self, price, html=False, **kwargs):
         """
